@@ -1,6 +1,7 @@
 import asyncio
 import importlib
 import importlib.util
+import json
 import logging
 import os
 import sys
@@ -14,7 +15,7 @@ sys.path.append(str(os.path.dirname(__file__)))
 sys.path.append(str(Path(os.path.dirname(__file__)) / 'proto'))
 
 name = 'locapip'
-version = __version__ = '0.1.16'
+version = __version__ = '0.1.17'
 
 server_port = 6547
 config = {}
@@ -46,12 +47,18 @@ def _import_module():
         spec.loader.exec_module(module[proto])
 
 
-def import_module(names):
+def update_module(config_path):
+    if Path(config_path).is_file():
+        config.update(json.loads(Path(config_path).read_text()))
+
+
+def reload_module():
     """
     only for client
     """
-    config.update({_: {} for _ in names})
-    _import_module()
+    if server is None:
+        config.update({_: {} for _ in ['test', 'explorer', 'dicom', 'fit_fill']})
+        _import_module()
 
 
 async def _serve(port: int):
