@@ -15,7 +15,7 @@ def main(port: int, config, logging):
         locapip.init_logging(logging)
 
     if config is not None:
-        locapip.config.update(json.loads(Path(config).read_text()))
+        locapip.update_module(config)
 
     locapip.serve(port)
 
