@@ -1,20 +1,20 @@
 import locale
 
-import itk
-
 import dicom_pb2 as pb
 import dicom_pb2_grpc as pb_rpc
 import locapip
 
 locale.setlocale(locale.LC_ALL, 'zh_CN.UTF-8')
-itk.ProcessObject.SetGlobalWarningDisplay(False)
-
-server_resolved_path = locapip.module['explorer'].server_resolved_path
 
 if locapip.server is not None:
+    import itk
+
+    itk.ProcessObject.SetGlobalWarningDisplay(False)
+
+
     class Service(pb_rpc.DicomServicer):
         async def parse_series(self, request: pb.Path, context):
-            path = server_resolved_path(request.path)
+            path = locapip.module['explorer'].server_resolved_path(request.path)
 
             io = itk.GDCMImageIO.New()
 
