@@ -19,7 +19,6 @@ async def _apass(*args, **kwargs):
 if locapip.server is not None:
     mesh_reset = {'DynamicBody': _apass, 'StaticBody': _apass}
     mesh_build = {'DynamicBody': _pass, 'StaticBody': _pass}
-    server_resolved_path = locapip.module['explorer'].server_resolved_path
 
 
     def new_stage(message):
@@ -37,13 +36,13 @@ if locapip.server is not None:
         async def import_mesh(self, request, context):
             name = request.name
             server_path = request.server_path
-            server_path = server_resolved_path(server_path)
+            server_path = locapip.module['explorer'].server_resolved_path(server_path)
             point_num, face_num = await mesh_reset[name](str(server_path))
             mesh_build[name]()
             return pb.MeshInfo(name=name, point_num=point_num, face_num=face_num)
 
         async def simulate(self, request, context):
-            request.capture_path = str(server_resolved_path(request.capture_path))
+            request.capture_path = str(locapip.module['explorer'].server_resolved_path(request.capture_path))
             return Parse(await simulate(MessageToJson(request, True, True)), pb.SimulateResult())
 
 
@@ -135,22 +134,24 @@ else:
         locapip.run_rpc(url, 'fit_fill', 'new_stage', [_request('new_stage', {})], [_response])
 
 
-    def upload_mesh(url: str, message):
+    def define_static_body(url: str, message):
         if message is str:
             message = json.loads(message)
 
-        name = message['name']
-        path = message['path']
-
-        server_path = f'cache/fit_fill/{name}.stl'
-
-        locapip.module['explorer'].copy(url, {
-            'copy_type': 'upload',
-            'client_path': path,
-            'server_path': server_path})
+        server_path = message['server_path']
 
         locapip.run_rpc(url, 'fit_fill', 'import_mesh',
-                        _request('import_mesh', {'name': name, 'server_path': server_path}),
+                        _request('import_mesh', {'name': 'StaticBody', 'server_path': server_path}),
+                        _response)
+
+    def define_dynamic_body(url: str, message):
+        if message is str:
+            message = json.loads(message)
+
+        server_path = message['server_path']
+
+        locapip.run_rpc(url, 'fit_fill', 'import_mesh',
+                        _request('import_mesh', {'name': 'DynamicBody', 'server_path': server_path}),
                         _response)
 
 
@@ -166,6 +167,6 @@ else:
             transform = [_['values'] for _ in [t['matrix'][_] for _ in t['matrix']][0]]
             return str()
 
-        capture = 'cache/fit_fill/capture/Capture'
+        capture = '.cache/fit_fill/capture/Capture'
         locapip.run_rpc(url, 'fit_fill', 'simulate', [_request('simulate', {'capture_path': capture})], [response])
         return transform
